[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,60 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/experimental/__stf/allocators/adapters.cuh>
|
||||
#include <cuda/experimental/stf.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
int main()
|
||||
{
|
||||
double* d_ptrA;
|
||||
const size_t N = 128 * 1024;
|
||||
const size_t NITER = 10;
|
||||
|
||||
// User allocated memory
|
||||
cuda_safe_call(cudaMalloc(&d_ptrA, N * sizeof(double)));
|
||||
|
||||
async_resources_handle handle;
|
||||
|
||||
cudaStream_t stream;
|
||||
cuda_safe_call(cudaStreamCreate(&stream));
|
||||
|
||||
for (size_t i = 0; i < NITER; i++)
|
||||
{
|
||||
graph_ctx ctx(stream, handle);
|
||||
|
||||
// The uncached allocator of the context will be using cudaMallocAsync(...,
|
||||
// stream) to avoid creating memory nodes in the graph (because they are
|
||||
// costly and caching the graph also keeps memory allocated)
|
||||
auto wrapper = stream_adapter(ctx, stream);
|
||||
|
||||
ctx.set_allocator(block_allocator<buddy_allocator>(ctx, wrapper.allocator()));
|
||||
|
||||
auto A = ctx.logical_data(make_slice(d_ptrA, N), data_place::current_device());
|
||||
|
||||
for (size_t k = 0; k < 4; k++)
|
||||
{
|
||||
auto tmp = ctx.logical_data(A.shape());
|
||||
auto tmp2 = ctx.logical_data(A.shape());
|
||||
// Test device and managed memory
|
||||
ctx.parallel_for(A.shape(), A.read(), tmp.write(), tmp2.write(data_place::managed()))
|
||||
->*[] __device__(size_t i, auto a, auto tmp, auto tmp2) {
|
||||
tmp(i) = a(i);
|
||||
tmp2(i) = a(i);
|
||||
};
|
||||
}
|
||||
|
||||
ctx.finalize();
|
||||
|
||||
wrapper.clear();
|
||||
}
|
||||
cuda_safe_call(cudaStreamSynchronize(stream));
|
||||
}
|
||||
Reference in New Issue
Block a user